@@ -159,6 +159,14 @@ extern ssize_t (*fkt_sendfile)(struct file *, loff_t *, size_t, read_actor_t, vo
 								(unsigned int)(P3), (unsigned int)(P4), \
 								(unsigned int)(P5) ); \
 								} while(0)
+#define FKT_ALWAYS_PROBE6(KEYMASK,CODE,P1,P2,P3,P4,P5,P6) \
+								do { \
+								if( KEYMASK & fkt_active ) \
+								fkt_header( (((unsigned int)(CODE))<<8) | 7, \
+								(unsigned int)(P1), (unsigned int)(P2), \
+								(unsigned int)(P3), (unsigned int)(P4), \
+								(unsigned int)(P5), (unsigned int)(P6) ); \
+								} while(0)
 
 #else /* CONFIG_FKT || CONFIG_FKT_MODULE */
 
@@ -169,6 +177,7 @@ extern ssize_t (*fkt_sendfile)(struct file *, loff_t *, size_t, read_actor_t, vo
 #define FKT_ALWAYS_PROBE3(MASK,CODE,P1,P2,P3)			do {} while (0)
 #define FKT_ALWAYS_PROBE4(MASK,CODE,P1,P2,P3,P4)		do {} while (0)
 #define FKT_ALWAYS_PROBE5(MASK,CODE,P1,P2,P3,P4,P5)		do {} while (0)
+#define FKT_ALWAYS_PROBE6(MASK,CODE,P1,P2,P3,P4,P5,P6)		do {} while (0)
 
 #endif
 
@@ -187,6 +196,7 @@ extern ssize_t (*fkt_sendfile)(struct file *, loff_t *, size_t, read_actor_t, vo
 #define FKT_PROBE4(KEYMASK,CODE,P1,P2,P3,P4)	FKT_ALWAYS_PROBE0(KEYMASK,CODE)
 
 #define FKT_PROBE5(KEYMASK,CODE,P1,P2,P3,P4,P5)	FKT_ALWAYS_PROBE0(KEYMASK,CODE)
+#define FKT_PROBE6(KEYMASK,CODE,P1,P2,P3,P4,P5,P6)	FKT_ALWAYS_PROBE0(KEYMASK,CODE)
 
 #else	/* CONFIG_FKT_TIME_ONLY */
 
@@ -203,6 +213,7 @@ extern ssize_t (*fkt_sendfile)(struct file *, loff_t *, size_t, read_actor_t, vo
 #define FKT_PROBE4(KEYMASK,CODE,P1,P2,P3,P4)	FKT_ALWAYS_PROBE4(KEYMASK,CODE,P1,P2,P3,P4)
 
 #define FKT_PROBE5(KEYMASK,CODE,P1,P2,P3,P4,P5)	FKT_ALWAYS_PROBE5(KEYMASK,CODE,P1,P2,P3,P4,P5)
+#define FKT_PROBE6(KEYMASK,CODE,P1,P2,P3,P4,P5,P6)	FKT_ALWAYS_PROBE5(KEYMASK,CODE,P1,P2,P3,P4,P5,P6)
 
 #endif	/* CONFIG_FKT_TIME_ONLY */
 
