@@ -4,7 +4,7 @@
 					fkt_record using fkt (fast kernel tracing) in the kernel.
 
 	Copyright (C) 2000, 2001  Robert D. Russell -- rdr@unh.edu
-				  2003, 2004  Samuel Thibault -- samuel.thibault@ens-lyon.org
+	2003, 2004, 2012  Samuel Thibault -- samuel.thibault@ens-lyon.org
 
 	This program is free software; you can redistribute it and/or modify
 	it under the terms of the GNU General Public License as published by
@@ -1986,16 +1986,16 @@ if( newfun_pos > 0 )
 
 void get_the_time( time_t the_time, char *message )
 	{
-	struct tm	breakout;
+	struct tm	*breakout;
 	char		buffer[128];
 
 
-	if( localtime_r(&the_time, &breakout) == NULL )
+	if( (breakout = localtime(&the_time)) == NULL )
 		{
 		fprintf(stderr, "Unable to break out %s\n", message);
 		exit(EXIT_FAILURE);
 		}
-	if( strftime(buffer, 128, "%d-%b-%Y %H:%M:%S", &breakout) == 0 )
+	if( strftime(buffer, 128, "%d-%b-%Y %H:%M:%S", breakout) == 0 )
 		{
 		fprintf(stderr, "Unable to convert %s\n", message);
 		exit(EXIT_FAILURE);
