@@ -143,7 +143,7 @@ __BEGIN_TEMPLATE__
 				fut_getstampedbuffer(FUT_CODE(CODE, __nbargs), FUT_SIZE(__nbargs)); \
 			__ARGS_REGISTER__				\
 			memcpy(__args, __s, __len);				\
-			memset((void*)__args+__len, 0, __nbargs_str*sizeof(long)-__len);	\
+			memset((char*)__args+__len, 0, __nbargs_str*sizeof(long)-__len);	\
 			fut_commitstampedbuffer(FUT_SIZE(__nbargs)); \
 		}							\
 	} while (0)
@@ -157,7 +157,7 @@ __END_TEMPLATE__
 			unsigned long *__args __attribute__((unused)) =	\
 				fut_getstampedbuffer(CODE, FUT_SIZE(__n)); \
 			memcpy(__args, __s, __len);			\
-			memset((void*)__args+__len, 0, __n*sizeof(long)-__len);	\
+			memset((char*)__args+__len, 0, __n*sizeof(long)-__len);	\
 			fut_commitstampedbuffer(FUT_SIZE(__n)); \
 		}							\
 	} while (0)
