@@ -55,14 +55,22 @@
 /*	set to non-zero when probing is active */
 volatile unsigned int fut_active = 0;
 
-/*	points to next unused byte in buffer (multiple of 4) */
+/*	points to next unused byte in buffer (multiple of long) */
 unsigned long * volatile fut_next_slot = NULL;
 
-/*	points to byte beyond end of buffer (multiple of 4) */
+/*	points to byte at beginning of buffer */
+unsigned long * volatile fut_first_slot = NULL;
+
+/*	points to byte beyond end of buffer (multiple of long) */
 unsigned long * volatile fut_last_slot = NULL;
 
+/*	Gives the amount of data which has been filled */
+size_t volatile fut_filled_slot = 0;
+
+#if USE_SPINLOCKS
 /*	Protects the fut_*_slot pointers */
 pthread_spinlock_t fut_slot_lock;
+#endif /* USE_SPINLOCKS */
 
 fxt_t fut;
 static struct fxt_infos *fut_infos;
@@ -92,18 +100,22 @@ static int already_flushed = 0;
 
 void fut_set_filename(char* filename)
 {
+  pthread_mutex_lock(&fut_flush_lock);
   if(fut_filename) {
     if(already_flushed)
-      fprintf(stderr, "Warning: change output file name to %s, but some events have been saved in file %s\n",
-	      filename, fut_filename);
+      /* Oops, we have already created the file, rename it */
+      if (rename(fut_filename, filename))
+	      fprintf(stderr,"could not rename %s into %s: %s\nWas another FxT process perhaps also using %s, on this machine, or on another machine through a shared filesystem?\n", fut_filename, filename, strerror(errno), fut_filename);
     free(fut_filename);
   }
   fut_filename = strdup(filename);
+  pthread_mutex_unlock(&fut_flush_lock);
 }
 
 void __fut_reset_pointers()
 {
   fut_next_slot = (unsigned long *)bufptr;
+  fut_filled_slot = 0;
 }
 
 void dumptime( time_t *the_time, clock_t *the_jiffies)
@@ -191,6 +203,7 @@ int fut_setup( unsigned int nlongs, unsigned int keymask, unsigned int threadid
 	 * actually initialized. This also avoids page faults while tracing. */
 	memset(bufptr, 0, nbytes);
 
+	fut_first_slot = (unsigned long *)bufptr;
 	fut_last_slot = (unsigned long *)(bufptr + nbytes);
 
 	/*	touch all pages so they get loaded */
@@ -203,7 +216,11 @@ int fut_setup( unsigned int nlongs, unsigned int keymask, unsigned int threadid
 	dumptime(&fut_infos->start_time, &fut_infos->start_jiffies);
 
 	fut_next_slot = (unsigned long *)bufptr;
+	fut_filled_slot = 0;
+#if USE_SPINLOCKS
 	pthread_spin_init(&fut_slot_lock, 0);
+#endif
+
 	fut_active = keymask & FULL_ACTIVE_MASK;
 
 	FUT_PROBE1(FUT_GCC_INSTRUMENT_KEYMASK,
@@ -306,6 +323,7 @@ int fut_reset( unsigned int keymask, unsigned int threadid )
 	/* reset the buffer to completely empty */
 	fut_last_slot = (unsigned long *)(bufptr + nallocated);
 	fut_next_slot = (unsigned long *)bufptr;
+	fut_filled_slot = 0;
 	fut_active = keymask & FULL_ACTIVE_MASK;
 	nlongs = nallocated / sizeof(long);
 
