@@ -1,5 +1,5 @@
 /*
- *  Copyright (C) 2004, 2011  Samuel Thibault <samuel.thibault@ens-lyon.org>
+ *  Copyright (C) 2004, 2011-2012  Samuel Thibault <samuel.thibault@ens-lyon.org>
  *
  * This program is free software ; you can redistribute it and/or modify
  * it under the terms of the GNU General Public License as published by
@@ -22,7 +22,10 @@
 #include <unistd.h>
 #include <stdint.h>
 #include <string.h>
+#ifndef __MINGW32__
 #include <sys/utsname.h>
+#include <arpa/inet.h>
+#endif
 #include <fcntl.h>
 #include <errno.h>
 #include "fxt.h"
@@ -33,7 +36,9 @@ struct fxt_block *__fxt_block_current=NULL;
 
 fxt_t fxt_setinfos(unsigned int space) {
 	fxt_t fxt;
+#ifndef __MINGW32__
 	struct utsname unameinfo;
+#endif
 	char *unamestr;
 	int n;
 
@@ -49,6 +54,10 @@ fxt_t fxt_setinfos(unsigned int space) {
 	fxt->infos.record_pid = getpid();
 	fxt->infos.page_size = getpagesize();
 
+#ifdef __MINGW32__
+	unamestr=malloc(7+1);
+	snprintf(unamestr,7+1,"mingw32");
+#else
 	if (uname(&unameinfo))
 		goto outfxt;
 	n = snprintf(NULL,0,"%s %s %s %s %s",
@@ -66,6 +75,7 @@ fxt_t fxt_setinfos(unsigned int space) {
 				unameinfo.release,
 				unameinfo.version,
 				unameinfo.machine);
+#endif
 
 	fxt->infos.uname=unamestr;
 
@@ -121,7 +131,7 @@ int fxt_fdwrite(fxt_t fxt, int fd) {
 	int ret;
 
 	/* main block */
-	WRITE(32,htonl(fxt->infos.arch));
+	WRITE(32,myhtonl(fxt->infos.arch));
 	BEGIN_BLOCK(fd, FXT_BLOCK_INFOS);
 
 	BEGIN_BLOCK(fd, FXT_BLOCK_TIME);
@@ -277,7 +287,7 @@ fxt_t fxt_fdopen(int fd) {
 		perror("read arch");
 		goto outf;
 	}
-	fxt->infos.arch = ntohl(fxt->infos.arch);
+	fxt->infos.arch = myntohl(fxt->infos.arch);
 	ENTER_FBLOCK_TYPE(fstream, FXT_BLOCK_INFOS); /* main block */
 	ENTER_FBLOCK_TYPE(fstream, FXT_BLOCK_TIME);
 	if ((ret = fxt_load_time(fxt, fstream))<0) goto outmalloc;
