@@ -355,7 +355,7 @@ enum {
 	FXT_BLOCK_TRACES_USER_RAW64,
 };
 
-unsigned long* __fut_record_event(fxt_trace_user_raw_t * rec, unsigned long code);
+unsigned long* __fut_record_event(fxt_trace_user_raw_t * rec, uint64_t stamp, unsigned long code);
 int fut_flush( char* filename, void* next_slot, int record_flush_events );
 void __fut_reset_pointers();
 
