@@ -144,7 +144,7 @@ int fkt_record_irqs(fxt_t fxt, int fd)
 	return 0;
 	}
 
-int fkt_load_irqs( fxt_t fxt, int fd )
+int fkt_load_irqs( fxt_t fxt, FILE *fstream )
 	{
 	struct code_list_item	*ptr;
 	unsigned int		i, k, n;
@@ -152,13 +152,13 @@ int fkt_load_irqs( fxt_t fxt, int fd )
 	char					*name;
 
 
-	if( read(fd, (void *)&fxt->nirqs, sizeof(fxt->nirqs)) <= 0 )
+	if( fread((void *)&fxt->nirqs, sizeof(fxt->nirqs), 1, fstream) <= 0 )
 		{
 		perror("read nirqs");
 		return -1;
 		}
 	//printf("%14s = %u\n", "nirqs", fxt->nirqs);
-	if( read(fd, (void *)&ncpus, sizeof(ncpus)) <= 0 )
+	if( fread((void *)&ncpus, sizeof(ncpus), 1, fstream) <= 0 )
 		{
 		perror("read ncpus");
 		return -1;
@@ -168,11 +168,11 @@ int fkt_load_irqs( fxt_t fxt, int fd )
 	for( n = 0;  n < fxt->nirqs;  n++ )
 		{/* build circular list with 1 item for each interrupt */
 		ptr = (struct code_list_item *)malloc(sizeof(struct code_list_item));
-		read(fd, (void *)&ptr->code, sizeof(ptr->code));
-		read(fd, (void *)&i, sizeof(i));
+		fread((void *)&ptr->code, sizeof(ptr->code), 1, fstream);
+		fread((void *)&i, sizeof(i), 1, fstream);
 		k = (i + 3) & ~3;
 		name = malloc(k);
-		read(fd, (void *)name, k);
+		fread((void *)name, 1, k, fstream);
 		name[i-1] = '\0';
 		ptr->name = name;
 		if( fxt->irq_list == NULL )
